shellCommand = Turbine.ShellCommand()
function shellCommand:Execute(command, args)
	if args=="" then
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Available commands:</rgb>")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh options</rgb> <rgb=#DDDDDD>Show settings window.</rgb>")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh showall</rgb> <rgb=#DDDDDD>Show all gambits.</rgb>")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh rebuild</rgb> <rgb=#DDDDDD>Rebuilds available gambits</rgb>.")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh reset</rgb> <rgb=#DDDDDD>Resets default positions.</rgb>")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh ooc</rgb> <rgb=#DDDDDD>Toggle out of combat visibility.</rgb>")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh icons</rgb> <rgb=#DDDDDD>Enable/disable gambit icons.</rgb>")
		Turbine.Shell.WriteLine("<rgb=#9ACD32>/gh vitals</rgb> <rgb=#DDDDDD>Enable/disable vitals display.</rgb>")
	end
	
	if (_ghSettings == nil) then -- command only need to work when options gui is not open.
	if args=="showall" then
		ToggleShowAll()
	end
	
	if args=="vitals" then
		ToggleVitals()
	end
	
	if args=="icons" then
		ToggleIcons()
	end
	
	if args=="win1" then
		ToggleWin1()
	end	
	
	if args=="win2" then
		ToggleWin2()
	end	
	
	if args=="reset" then
		Reset()
	end
	
	if args=="rebuild" then
		Rebuild()
	end
	
	if args=="options" then
		if (_ghSettings == nil) then
			_ghSettings = GambitHelper2.Settings()
			_ghSettings:SetVisible(true)
			
			-- aseta uudet win arvot...
						
			UpdateDisplay()
		end
	end
		
	if args=="ooc" then
		ToggleOOC()
	end	
	end
end

function ToggleVitals()
	_ghData.vitals=not(_ghData.vitals)
	if (_ghData.vitals) then
		moraleBar:SetVisible (_ghData.ooc_visibility)
		powerBar:SetVisible (_ghData.ooc_visibility)
	else
		moraleBar:SetVisible (false)
		powerBar:SetVisible (false)
	end
	if _ghData.vitals then
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Vitals display is now enabled.</rgb>")
	else
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Vitals display is now disabled.</rgb>")
	end
end

function ToggleIcons()
	_ghData.icons=not(_ghData.icons)
	if _ghData.icons then
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Gambits icons are now visible.</rgb>")
	else
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Gambits icons are now hidden.</rgb>")
	end
	UpdateDisplay()
end

function ToggleShowAll()
	_ghData.showall=not(_ghData.showall)
	if _ghData.showall then
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>All gambits are now visible.</rgb>")
	else
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Only known gambits are now visible.</rgb>")
	end
	FilterGambitList()
	UpdateDisplay()
end

function Reset()
	local _displayWidth, _displayHeight = Turbine.UI.Display.GetSize();
	local _centerX = _displayWidth/2;
	local _centerY = _displayHeight/2;
	GambitWindow1:SetPosition(_centerX-396,_centerY-100)
	GambitWindow2:SetPosition(_centerX+198,_centerY-100)
	Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Default positions restored.</rgb>")
		-- refresh dragbars
	GambitWindow1.DragBar:Refresh()
	GambitWindow2.DragBar:Refresh()
end

function Rebuild()
	FilterGambitList()
	UpdateDisplay()
	Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>List of gambits refreshed.</rgb>")
		-- refresh dragbars
	GambitWindow1.DragBar:Refresh()
	GambitWindow2.DragBar:Refresh()
end

function ToggleOOC()
	_ghData.ooc_visibility=not(_ghData.ooc_visibility)
	if (_ghSettings == nil) then
		GambitWindow1:SetVisible (_ghData.ooc_visibility)
		GambitWindow2:SetVisible (_ghData.ooc_visibility)
		if (_ghData.vitals) then
			moraleBar:SetVisible (_ghData.ooc_visibility)
			powerBar:SetVisible (_ghData.ooc_visibility)
		else
			moraleBar:SetVisible (false)
			powerBar:SetVisible (false)
		end
	end
	if _ghData.ooc_visibility then
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>OOC Visibility is now set ON.</rgb>")
	else
		Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>OOC Visibility is now set OFF.</rgb>")
	end
end

-- Save all settings
function SaveSettings()
	_ghData.x1,_ghData.y1=GambitWindow1:GetPosition() --take current location
	_ghData.x2,_ghData.y2=GambitWindow2:GetPosition() --take current location
		
	Turbine.PluginData.Save( Turbine.DataScope.Character, "GambitHelper2", settingsEncode(_ghData))--store everything
	
	Turbine.Shell.WriteLine("<rgb=#9ACD32>Gambit Helper:</rgb> <rgb=#DDDDDD>Settings saved.</rgb>") --notify player...
	
end

function settingsEncode(t)
	local t2={};
	for k,v in pairs(t) do
		if(type(v)=="number")then
			v=tostring(v);
		elseif (type(v)=="table")then
			v=settingsEncode(v);
		end
		t2[k]=v;
	end
	return t2
end

function settingsDecode(t)
	local t2={};
	for k,v in pairs(t) do
		if(tonumber(v)~=nil)then
			v=tonumber(v);
		elseif (type(v)=="table")then
			v=settingsDecode(v);
		end
		t2[k]=v;
	end
	return t2
end

Turbine.Shell.AddCommand('gh', shellCommand)